@@ -10,6 +10,10 @@
 #define SYCONFIG_H
 
 #define SWITCHYARD_LWRP_VERSION "1.1"
+#define SWITCHYARD_LWRP_CONNECTION_TIMEOUT 5000
+#define SWITCHYARD_LWRP_WATCHDOG_INTERVAL_MIN 60000.0
+#define SWITCHYARD_LWRP_WATCHDOG_INTERVAL_MAX 180000.0
+#define SWITCHYARD_LWRP_WATCHDOG_RETRY 10000
 #define SWITCHYARD_ADVERTS_ADDRESS "239.192.255.3"
 #define SWITCHYARD_ADVERTS_PORT 4001
 #define SWITCHYARD_CLOCK_ADDRESS "239.192.255.2"
