@@ -6,9 +6,12 @@
 //     All Rights Reserved.
 //
 
+#include <QStringList>
+
 #include "sydestination.h"
 
 SyDestination::SyDestination()
+  : SyEndPoint()
 {
   dst_channels=2;
 }
@@ -20,6 +23,13 @@ QHostAddress SyDestination::streamAddress() const
 }
 
 
+void SyDestination::setStreamAddress(const QString &addr)
+{
+  QStringList f0=addr.split(" ");
+  setStreamAddress(QHostAddress(f0[0]));
+}
+
+
 void SyDestination::setStreamAddress(const QHostAddress &addr)
 {
   dst_stream_address=addr;
