@@ -9,14 +9,17 @@
 #ifndef SYDESTINATION_H
 #define SYDESTINATION_H
 
-#include <QtCore/QString>
-#include <QtNetwork/QHostAddress>
+#include <QHostAddress>
+#include <QString>
 
-class SyDestination
+#include <sy/syendpoint.h>
+
+class SyDestination : public SyEndPoint
 {
  public:
   SyDestination();
   QHostAddress streamAddress() const;
+  void setStreamAddress(const QString &addr);
   void setStreamAddress(const QHostAddress &addr);
   QString name() const;
   void setName(const QString &name);
