@@ -9,9 +9,11 @@
 #include "sysource.h"
 
 SySource::SySource(const QHostAddress &s_addr,const QString &name,bool enabled)
+  : SyEndPoint()
 {
   src_stream_address=s_addr;
   src_name=name;
+  src_label="";
   src_enabled=enabled;
   src_channels=2;
   src_packet_size=240;
@@ -20,6 +22,7 @@ SySource::SySource(const QHostAddress &s_addr,const QString &name,bool enabled)
 
 
 SySource::SySource()
+  : SyEndPoint()
 {
 }
 
@@ -48,6 +51,18 @@ void SySource::setName(const QString &name)
 }
 
 
+QString SySource::label() const
+{
+  return src_label;
+}
+
+
+void SySource::setLabel(const QString &str)
+{
+  src_label=str;
+}
+
+
 bool SySource::enabled() const
 {
   return src_enabled;
